=== modified file '__init__.py'
--- __init__.py	2006-03-15 19:46:05 +0000
+++ __init__.py	2006-03-15 20:16:00 +0000
@@ -49,7 +49,11 @@
 
     def run(self, branch_url):
         from lp_registration import BranchRegistrationRequest
-        BranchRegistrationRequest(branch_url)
+        def _find_default_branch_id(branch_url):
+            i = branch_url.rfind('/')
+            return branch_url[i+1:]
+        branch_id = _find_default_branch_id(branch_url)
+        BranchRegistrationRequest(branch_url, branch_id)
 
 register_command(cmd_register_branch)
 

=== modified file 'lp_registration.py'
--- lp_registration.py	2006-03-15 19:46:05 +0000
+++ lp_registration.py	2006-03-15 20:16:00 +0000
@@ -18,21 +18,34 @@
 import xmlrpclib
 ## from twisted.web import xmlrpc
 
+
+# TODO: use last component of path as default id?
+
 class BranchRegistrationRequest(object):
     """Request to tell Launchpad about a bzr branch."""
 
-    def __init__(self, branch_url):
+    _methodname = 'register_branch'
+
+    def __init__(self, branch_url, branch_id):
         self.branch_url = branch_url
+        self.branch_id = branch_id
+        self.branch_description = None
+        self.owner_email = None
 
     def _request_xml(self):
         """Return the string form of the xmlrpc request."""
         return xmlrpclib.dumps(self._request_params(),
-                               methodname='register_branch',
+                               methodname=self._methodname,
                                allow_none=True)
 
     def _request_params(self):
         """Return xmlrpc request parameters"""
+        # This must match the parameter tuple expected by Launchpad for this
+        # method
         return (self.branch_url,
+                self.branch_id,
+                self.branch_description,
+                self.owner_email,
                )
 
 

=== modified file 'test_register.py'
--- test_register.py	2006-03-15 19:56:15 +0000
+++ test_register.py	2006-03-15 20:16:00 +0000
@@ -23,6 +23,8 @@
 
 class TestBranchRegistration(TestCase):
     SAMPLE_URL = 'http://bazaar-vcs.org/bzr/bzr.dev/'
+    SAMPLE_OWNER = 'jhacker@foo.com'
+    SAMPLE_BRANCH_ID = 'bzr.dev'
 
     def test_register_help(self):
         out, err = self.run_bzr('register-branch', '--help')
@@ -35,12 +37,8 @@
         """Register a well-known branch to fake server"""
         self.run_bzr('register-branch', self.SAMPLE_URL)
 
-    def test_make_branch_registration(self):
-        from lp_registration import BranchRegistrationRequest
-        rego = BranchRegistrationRequest(self.SAMPLE_URL)
-
     def test_request_xml(self):
-        rego = BranchRegistrationRequest(self.SAMPLE_URL)
+        rego = BranchRegistrationRequest(self.SAMPLE_URL, self.SAMPLE_BRANCH_ID)
         req_xml = rego._request_xml()
         # other representations are possible; this is a bit hardcoded to
         # python's xmlrpclib
@@ -52,14 +50,22 @@
 <param>
 <value><string>%s</string></value>
 </param>
+<param>
+<value><string>bzr.dev</string></value>
+</param>
+<param>
+<value><nil/></value></param>
+<param>
+<value><nil/></value></param>
 </params>
 </methodCall>
 ''' % self.SAMPLE_URL)
 
     def test_request_roundtrip(self):
         """Check the request can be parsed and meets the interface spec"""
-        rego = BranchRegistrationRequest(self.SAMPLE_URL)
+        rego = BranchRegistrationRequest(self.SAMPLE_URL, self.SAMPLE_BRANCH_ID)
         req_xml = rego._request_xml()
         unpacked, method = xmlrpclib.loads(req_xml)
-        self.assertEquals(unpacked, (self.SAMPLE_URL, ))
+        self.assertEquals(unpacked,
+                          (self.SAMPLE_URL, self.SAMPLE_BRANCH_ID, None, None))
         self.assertEquals(method, 'register_branch')

